# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.add_on_configuration import AddOnConfiguration

class TestAddOnConfiguration(unittest.TestCase):
    """AddOnConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AddOnConfiguration:
        """Test AddOnConfiguration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AddOnConfiguration`
        """
        model = AddOnConfiguration()
        if include_optional:
            return AddOnConfiguration(
                can_do_content_expansion = True,
                can_import_to_wordpress = True,
                key = '',
                wp_admin = '',
                wp_json = ''
            )
        else:
            return AddOnConfiguration(
        )
        """

    def testAddOnConfiguration(self):
        """Test AddOnConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.token_response import TokenResponse

class TestTokenResponse(unittest.TestCase):
    """TokenResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenResponse:
        """Test TokenResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenResponse`
        """
        model = TokenResponse()
        if include_optional:
            return TokenResponse(
                access_token = '',
                refresh_token = ''
            )
        else:
            return TokenResponse(
        )
        """

    def testTokenResponse(self):
        """Test TokenResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability import ContentEvaluationResponseQualityScoreBreakdownReadability

class TestContentEvaluationResponseQualityScoreBreakdownReadability(unittest.TestCase):
    """ContentEvaluationResponseQualityScoreBreakdownReadability unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentEvaluationResponseQualityScoreBreakdownReadability:
        """Test ContentEvaluationResponseQualityScoreBreakdownReadability
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentEvaluationResponseQualityScoreBreakdownReadability`
        """
        model = ContentEvaluationResponseQualityScoreBreakdownReadability()
        if include_optional:
            return ContentEvaluationResponseQualityScoreBreakdownReadability(
                score = 1.337,
                grade_level = 56,
                complex_sentences = wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability_complex_sentences.ContentEvaluationResponse_quality_score_breakdown_readability_complex_sentences(
                    hard = 56, 
                    very_hard = 56, 
                    total = 56, )
            )
        else:
            return ContentEvaluationResponseQualityScoreBreakdownReadability(
                score = 1.337,
                grade_level = 56,
                complex_sentences = wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability_complex_sentences.ContentEvaluationResponse_quality_score_breakdown_readability_complex_sentences(
                    hard = 56, 
                    very_hard = 56, 
                    total = 56, ),
        )
        """

    def testContentEvaluationResponseQualityScoreBreakdownReadability(self):
        """Test ContentEvaluationResponseQualityScoreBreakdownReadability"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.rules_api import RulesApi


class TestRulesApi(unittest.TestCase):
    """RulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RulesApi()

    def tearDown(self) -> None:
        pass

    def test_copy_rules(self) -> None:
        """Test case for copy_rules

        Copy
        """
        pass

    def test_create_rule(self) -> None:
        """Test case for create_rule

        Create
        """
        pass

    def test_delete_rule(self) -> None:
        """Test case for delete_rule

        Delete
        """
        pass

    def test_list_rules(self) -> None:
        """Test case for list_rules

        List
        """
        pass

    def test_update_rule(self) -> None:
        """Test case for update_rule

        Update
        """
        pass

    def test_update_rule_collection(self) -> None:
        """Test case for update_rule_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
